@@ -7,8 +7,7 @@ Data_impute <- function(data, inf = "inf", intensity = "LFQ", miss.value = NA,
                         distmethod = "manhattan", A.IAC = FALSE,
                         dohclust = FALSE, treelabels = NA,
                         plot = TRUE, filename = NULL,
-                        text.cex = 0.7, text.col = "red", text.pos = 1,
-                        text.labels = NA, abline.col = "red", abline.lwd = 2,
+                        text.labels = NA, abline.col = "red", abline.lwd = 1,
                         impute = TRUE, verbose = 1, ...){
   if (is.null(data[[inf]]) | is.null(data[[intensity]])) stop("data, inf or intensity is wrong.")
   if (!inherits(data[[intensity]],"data.frame")) #220517 class(data[[intensity]]) != "data.frame"
@@ -39,8 +38,7 @@ Data_impute <- function(data, inf = "inf", intensity = "LFQ", miss.value = NA,
                                          miss.value = miss.value, sdout = sdout,
                                          dohclust = dohclust, treelabels = treelabels,
                                          plot = plot, filename = filename,
-                                         text.cex = text.cex, text.col = text.col,
-                                         text.pos = text.pos, text.labels = text.labels,
+                                         text.labels = text.labels,
                                          abline.col = abline.col, abline.lwd = abline.lwd,
                                          ...)); #outlierdata change to intensity
     if (!inherits(data_deoutlier,"try-error"))  #220517 class(data_deoutlier) != "try-error"
@@ -245,14 +243,15 @@ Data_impute <- function(data, inf = "inf", intensity = "LFQ", miss.value = NA,
 #210728 the param:outilerdata change to param:intensity
 #210728 add a new choose in distmethod: bicor
 #210728 fix the plot and doclust plot
+#library(ggplot2)
+#library(ggrepel)
 .OutlierDetect <- function(data, iteration = NA, intensity = "intensity",
                            distmethod = "manhattan", A.IAC = FALSE,
                            maxNAratio = 0.5,
                            miss.value = NA, sdout = 2,
                            dohclust = FALSE, treelabels = NA,
                            plot = TRUE, filename = NULL,
-                           text.cex = 0.7, text.col = "red", text.pos = 1,
-                           text.labels = NA, abline.col = "red", abline.lwd = 2,
+                           text.labels = NA, abline.col = "red", abline.lwd = 1,
                            ...){
   distmethod <- match.arg(distmethod,
                           c("manhattan","euclidean", "canberra","correlation","bicor"));
@@ -263,6 +262,7 @@ Data_impute <- function(data, inf = "inf", intensity = "LFQ", miss.value = NA,
   outliersample = 1; outlier = NULL; iter = 0;
   if (!is.na(miss.value)) #210728 del; data[[outlierdata]][data[[outlierdata]] == miss.value] <- NA; #190716
     data[["intensity"]][data[["intensity"]] == miss.value] = NA;#210728
+  pic <- NULL # outlier sd plot will save in one file 250728
   while (outliersample > 0){
     iter <- iter + 1;
     if (distmethod %in% c("correlation","bicor"))
@@ -307,42 +307,37 @@ Data_impute <- function(data, inf = "inf", intensity = "LFQ", miss.value = NA,
         if(!dir.exists("plot")) dir.create("plot"); #210615fix exist plot dir
         pdf(paste0("plot/",filename, " sampleTree ",iter,".pdf")) #210728 save file in plot dir
       }
-      plot(sampleTree, main = "Sample clustering to detect outliers",
+      plot(sampleTree, main = paste0("Sample clustering to detect outliers ",iter),
            sub="", labels=treelabels,...);
       if (is.character(filename) & length(filename) == 1) dev.off()
       #cluster <- hclust(as.dist(1-IAC),method="average")
       #plot(cluster,cex=0.7,labels=dimnames(data$intensity)[[2]])
     }
-    #outliers
+    #outliers 250728
     if (plot) {
+      #250728
+      sddata <- data.frame(x = 1:length(numbersd),numbersd, samples = colnames(data$intensity))
       #210728
       if (length(text.labels)!= dim(data$intensity)[[2]] & !all(is.na(text.labels))) {
         text.labels = NA;
         warning("the number of text.labels is differ with sample number and use sample name instead of.")
       }
-      #210728 use textlabels instead of text.labels
-      if (all(is.na(text.labels))) textlabels <- out_name;
-      #210728
-      if (length(text.labels) == dim(data$intensity)[[2]]) {
-        textlabels <- text.labels[out_pos];
-        text.labels <- text.labels[-out_pos];
-      }
-      col <- rep("black", length(numbersd));
-      col[out_pos] <- "red";
-      pch <- rep(20, length(numbersd));
-      pch[out_pos] <- 21;
-      if (is.character(filename) & length(filename) == 1){
-        if(!dir.exists("plot")) dir.create("plot"); #210615fix exist plot dir
-        pdf(paste0("plot/",filename, " outliersample ",iter,".pdf")) #210728 save file in plot dir
-      }
-      plot(numbersd, pch = pch, bg = "red", col = col, xlab = "");
-      if (length(out_pos) > 0){
-        text(out_pos, numbersd[out_pos], labels = textlabels,
-             pos = text.pos, cex = text.cex, col = text.col);
-        abline(h = sdout, col = abline.col, lwd = abline.lwd);
-      }
-      if (is.character(filename) & length(filename) == 1) dev.off()
-      #text.labels <- NA;
+      if (all(is.na(text.labels))) text.labels <- colnames(data$intensity);
+      sddata$samples <- text.labels
+      sddata$label[sddata$numbersd > sdout] <- sddata$samples[sddata$numbersd > sdout]
+      sddata$col <- "black"
+      sddata$col[sddata$numbersd > sdout] <- "red"
+      sddata$pch <- 1;
+      sddata$pch[sddata$numbersd > sdout] <- 2
+      x <- sddata$x; label = sddata$label
+
+      pic <- c(pic,list(ggplot(sddata,aes(y = numbersd,x=x)) +
+        geom_point(color = sddata$col,size =sddata$pch) +
+        geom_text_repel(aes(label = label))+
+        labs(title = paste0("Sample varation in outlier detection ", iter))+
+        geom_line(y = sdout,col = abline.col,linewidth = abline.lwd) +
+        theme_bw()))
+      names(pic)[iter] <- paste0("Detect_",iter)
     }
     outliersample <- length(out_pos);
     outlier <- c(outlier, out_name);
@@ -358,6 +353,16 @@ Data_impute <- function(data, inf = "inf", intensity = "LFQ", miss.value = NA,
     }
     if (!is.na(iteration) & iter >= iteration) outliersample <- 0; #190716
   }
+  #250728
+  if(plot) {
+    if (is.character(filename) & length(filename) == 1){
+      if(!dir.exists("plot")) dir.create("plot"); #210615fix exist plot dir
+      pdf(paste0("plot/",filename, " outliersample.pdf"))
+    }
+    for( i in names(pic))
+      print(pic[[i]])
+    if (is.character(filename) & length(filename) == 1) dev.off()
+  }
   #if (!is.na(miss.value)) data[[outlierdata]][is.na(data[[outlierdata]])] <- miss.value; #190716
   if (!is.na(miss.value)) data[["intensity"]][is.na(data[["intensity"]])] <- miss.value; #210728
   list(outlier = outlier, data = data)
